@@ -15,7 +15,10 @@ import constructs._jsii
 import projen._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-prototyping-sdk/pipeline", "0.3.9", __name__[0:-6], "pipeline@0.3.9.jsii.tgz"
+    "@aws-prototyping-sdk/pipeline",
+    "0.3.10",
+    __name__[0:-6],
+    "pipeline@0.3.10.jsii.tgz",
 )
 
 __all__ = [
